Documentation
¶
Index ¶
- Variables
- func NewGroup(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
- func NewGroupInherit(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
- func NewSession(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
- func NewUser(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
- func NewUserGroup(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
- type DummyStruct
- type Group
- type GroupCollection
- func (d *GroupCollection) Delete() error
- func (c *GroupCollection) GetByID(id string) *Group
- func (t *GroupCollection) IncludeInherits() error
- func (t *GroupCollection) InheritsByGroupID() (map[string]*GroupCollection, error)
- func (d *GroupCollection) Map() []map[string]interface{}
- func (c *GroupCollection) Slice() []*Group
- func (d *GroupCollection) Update(r *pb.UpdateGroupData) error
- type GroupFactory
- type GroupFactoryInterface
- type GroupInherit
- type GroupInheritCollection
- type GroupInternalLibrary
- type Session
- type SessionCollection
- type SessionFactory
- type SessionFactoryInterface
- type SessionInternalLibrary
- type User
- type UserCollection
- func (d *UserCollection) Delete() error
- func (c *UserCollection) GetByID(id string) *User
- func (t *UserCollection) GroupsByUserID() (map[string]*GroupCollection, error)
- func (t *UserCollection) IncludeGroups() error
- func (d *UserCollection) Map() []map[string]interface{}
- func (c *UserCollection) Slice() []*User
- func (d *UserCollection) Update(r *pb.UpdateUserData) error
- type UserComputeUserGroupsResults
- type UserFactory
- type UserFactoryInterface
- type UserGetUserFromTokenResults
- type UserGroup
- type UserGroupCollection
- type UserInternalLibrary
- type UserLoginResults
- type UserRegisterResults
Constants ¶
This section is empty.
Variables ¶
var GroupAggregate *groupAggregate
GroupAggregate contain the definition of the group object.
*It is also used to generate the factory containing the main functions with the environnement.
var GroupEntity *groupEntity
var GroupInheritValueObject *groupInheritValueObject
var SessionAggregate *sessionAggregate
SessionAggregate contain the definition of the session object.
*It is also used to generate the factory containing the main functions with the environnement.
var SessionEntity *sessionEntity
var UserAggregate *userAggregate
UserAggregate contain the definition of the user object.
*It is also used to generate the factory containing the main functions with the environnement.
var UserEntity *userEntity
var UserGroupValueObject *userGroupValueObject
Functions ¶
func NewGroup ¶
func NewGroup(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
func NewGroupInherit ¶
func NewGroupInherit(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
func NewSession ¶
func NewSession(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
func NewUser ¶
func NewUser(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
func NewUserGroup ¶
func NewUserGroup(wk libdomain.WorkflowInterface) libdomain.DomainObjectInterface
Types ¶
type DummyStruct ¶
type DummyStruct struct{}
type Group ¶
type Group struct {
Pb *pb.Group
Workflow libdomain.WorkflowInterface
}
Group is the main struct for operating a group object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
type GroupCollection ¶
type GroupCollection struct {
*libdomain.Collection
}
GroupCollection is the main struct for operating a list group object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*GroupCollection) Delete ¶
func (d *GroupCollection) Delete() error
Delete will delete all the groups in the collection.
func (*GroupCollection) GetByID ¶
func (c *GroupCollection) GetByID(id string) *Group
GetByID return the group in this collection, by id.
func (*GroupCollection) IncludeInherits ¶
func (t *GroupCollection) IncludeInherits() error
func (*GroupCollection) InheritsByGroupID ¶
func (t *GroupCollection) InheritsByGroupID() (map[string]*GroupCollection, error)
InheritssByGroupID return the group behind Inherits field, for each group in the collection, by id.
func (*GroupCollection) Map ¶
func (d *GroupCollection) Map() []map[string]interface{}
func (*GroupCollection) Slice ¶
func (c *GroupCollection) Slice() []*Group
GetSlice return all groups in this collection, as a slice.
func (*GroupCollection) Update ¶
func (d *GroupCollection) Update(r *pb.UpdateGroupData) error
Update will update all the groups in the collection with the specified data.
type GroupFactory ¶
type GroupFactory struct {
*libdomain.Factory
GroupFactoryInterface
}
GroupFactory is the main struct for operating group objects, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*GroupFactory) Create ¶
func (d *GroupFactory) Create( groups []*pb.CreateGroupCommand, parentAggregate *libdata.Aggregate, ) (*GroupCollection, error)
Create create a new group from the factory, and return it.
func (*GroupFactory) New ¶
func (d *GroupFactory) New() *Group
New return a new instance of a group object.
func (*GroupFactory) NewCollection ¶
func (d *GroupFactory) NewCollection(records *libdomain.Collection) *GroupCollection
NewCollection return a new instance of a group collection object.
type GroupFactoryInterface ¶
type GroupFactoryInterface interface {
}
type GroupInherit ¶
type GroupInherit struct {
Pb *pb.GroupInherit
Workflow libdomain.WorkflowInterface
}
GroupInherit is the main struct for operating a groupInherit object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*GroupInherit) Delete ¶
func (t *GroupInherit) Delete() error
Delete will delete the groupInherit from the database.
func (*GroupInherit) GetID ¶
func (t *GroupInherit) GetID() string
SetID is a function to set the ID of the groupInherit.
func (*GroupInherit) JSON ¶
func (t *GroupInherit) JSON() ([]byte, error)
JSON is a function to return the groupInherit data in JSON format.
func (*GroupInherit) Map ¶
func (t *GroupInherit) Map() map[string]interface{}
Map is a function to return the groupInherit data in JSON format.
type GroupInheritCollection ¶
type GroupInheritCollection struct {
*libdomain.Collection
}
GroupInheritCollection is the main struct for operating a list groupInherit object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*GroupInheritCollection) GetByID ¶
func (c *GroupInheritCollection) GetByID(id string) *GroupInherit
GetByID return the groupInherit in this collection, by id.
func (*GroupInheritCollection) Slice ¶
func (c *GroupInheritCollection) Slice() []*GroupInherit
GetSlice return all groupInherits in this collection, as a slice.
type GroupInternalLibrary ¶
type GroupInternalLibrary struct {
NewGroupInheritFactory func(libdomain.WorkflowInterface) *groupInheritFactory
}
type Session ¶
type Session struct {
Pb *pb.Session
Workflow libdomain.WorkflowInterface
}
Session is the main struct for operating a session object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
type SessionCollection ¶
type SessionCollection struct {
*libdomain.Collection
}
SessionCollection is the main struct for operating a list session object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*SessionCollection) Delete ¶
func (d *SessionCollection) Delete() error
Delete will delete all the sessions in the collection.
func (*SessionCollection) GetByID ¶
func (c *SessionCollection) GetByID(id string) *Session
GetByID return the session in this collection, by id.
func (*SessionCollection) Map ¶
func (d *SessionCollection) Map() []map[string]interface{}
func (*SessionCollection) Slice ¶
func (c *SessionCollection) Slice() []*Session
GetSlice return all sessions in this collection, as a slice.
func (*SessionCollection) UsersBySessionID ¶
func (t *SessionCollection) UsersBySessionID() (map[string]*User, error)
UsersBySessionID return the user behind UserID field, for each session in the collection, by id.
type SessionFactory ¶
type SessionFactory struct {
*libdomain.Factory
SessionFactoryInterface
}
SessionFactory is the main struct for operating session objects, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*SessionFactory) Create ¶
func (d *SessionFactory) Create( sessions []*pb.CreateSessionCommand, parentAggregate *libdata.Aggregate, ) (*SessionCollection, error)
Create create a new session from the factory, and return it.
func (*SessionFactory) New ¶
func (d *SessionFactory) New() *Session
New return a new instance of a session object.
func (*SessionFactory) NewCollection ¶
func (d *SessionFactory) NewCollection(records *libdomain.Collection) *SessionCollection
NewCollection return a new instance of a session collection object.
type SessionFactoryInterface ¶
type SessionFactoryInterface interface {
}
type SessionInternalLibrary ¶
type SessionInternalLibrary struct {
}
type User ¶
type User struct {
Pb *pb.User
Workflow libdomain.WorkflowInterface
}
User is the main struct for operating a user object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
type UserCollection ¶
type UserCollection struct {
*libdomain.Collection
}
UserCollection is the main struct for operating a list user object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*UserCollection) Delete ¶
func (d *UserCollection) Delete() error
Delete will delete all the users in the collection.
func (*UserCollection) GetByID ¶
func (c *UserCollection) GetByID(id string) *User
GetByID return the user in this collection, by id.
func (*UserCollection) GroupsByUserID ¶
func (t *UserCollection) GroupsByUserID() (map[string]*GroupCollection, error)
GroupssByUserID return the group behind Groups field, for each user in the collection, by id.
func (*UserCollection) IncludeGroups ¶
func (t *UserCollection) IncludeGroups() error
func (*UserCollection) Map ¶
func (d *UserCollection) Map() []map[string]interface{}
func (*UserCollection) Slice ¶
func (c *UserCollection) Slice() []*User
GetSlice return all users in this collection, as a slice.
func (*UserCollection) Update ¶
func (d *UserCollection) Update(r *pb.UpdateUserData) error
Update will update all the users in the collection with the specified data.
type UserComputeUserGroupsResults ¶
ComputeUserGroups todo
type UserFactory ¶
type UserFactory struct {
*libdomain.Factory
UserFactoryInterface
}
UserFactory is the main struct for operating user objects, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*UserFactory) Create ¶
func (d *UserFactory) Create( users []*pb.CreateUserCommand, parentAggregate *libdata.Aggregate, ) (*UserCollection, error)
Create create a new user from the factory, and return it.
func (*UserFactory) New ¶
func (d *UserFactory) New() *User
New return a new instance of a user object.
func (*UserFactory) NewCollection ¶
func (d *UserFactory) NewCollection(records *libdomain.Collection) *UserCollection
NewCollection return a new instance of a user collection object.
type UserFactoryInterface ¶
type UserFactoryInterface interface {
}
type UserGetUserFromTokenResults ¶
GetUserFromToken todo
type UserGroup ¶
type UserGroup struct {
Pb *pb.UserGroup
Workflow libdomain.WorkflowInterface
}
UserGroup is the main struct for operating a userGroup object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
type UserGroupCollection ¶
type UserGroupCollection struct {
*libdomain.Collection
}
UserGroupCollection is the main struct for operating a list userGroup object, which shall
*be used in custom code because it contains the environnement informations and *the easy-to-use functions.
func (*UserGroupCollection) GetByID ¶
func (c *UserGroupCollection) GetByID(id string) *UserGroup
GetByID return the userGroup in this collection, by id.
func (*UserGroupCollection) Slice ¶
func (c *UserGroupCollection) Slice() []*UserGroup
GetSlice return all userGroups in this collection, as a slice.
type UserInternalLibrary ¶
type UserInternalLibrary struct {
NewUserGroupFactory func(libdomain.WorkflowInterface) *userGroupFactory
}
type UserRegisterResults ¶
Register todo